-- This class creates a quickslot control that has an image or text label over the quickslot. This is most useful when
-- using a quickslot to hold a programatically controlled alias which the programmer wishes to display as a button
-- rather than the rather ugly "/ALIAS" text

QSButton = class( Turbine.UI.Control );

function QSButton:Constructor(shortcutType, shortcutData)
	Turbine.UI.Control.Constructor( self );
	if shortcutType==nil then shortcutType=Turbine.UI.Lotro.ShortcutType.Alias end
	if shortcutData==nil then shortcutData="" end
	self.shortcutType=shortcutType;
	self.shortcutData=shortcutData;

	self.QS=Turbine.UI.Lotro.Quickslot();
	self.QS:SetParent(self);
	self.QS:SetAllowDrop(false); -- by default, turn off drag/drop
	self.QS.DragDrop=function()
		local sc=Turbine.UI.Lotro.Shortcut();
		sc:SetType(self.shortcutType);
		sc:SetData(self.shortcutData);
		local success,result=pcall(Turbine.UI.Lotro.Quickslot.SetShortcut,self.QS,sc);
	end
	self.QS:SetLeft(-36);

	self.Label=Turbine.UI.Label();
	self.Label:SetParent(self);
	self.Label:SetZOrder(1);
	self.Label:SetMouseVisible(false);

	local sc=Turbine.UI.Lotro.Shortcut();
	sc:SetType(shortcutType);
	sc:SetData(shortcutData);
	local success,result=pcall(Turbine.UI.Lotro.Quickslot.SetShortcut,self.QS,sc);

	self.SetType=function(sender,type)
		self.shortcutType=type;
		self.QS:SetType(type);
	end
	self.SetData=function(sender,data)
		self.shortcutData=data;
		local success,result=pcall(Turbine.UI.Lotro.Quickslot.SetData,self.QS,self.shortcutData);
	end
	self.GetData=function()
		return self.QS:GetData();
	end
	self.GetItem=function()
		return self.QS:GetItem();
	end
	self.GetType=function()
		return self.QS:GetType();
	end
	self.SetShortcut=function(sender,sc)
		if sc.GetData~=nil and sc.GetType~=nil then
			local success,result=pcall(Turbine.UI.Lotro.Quickslot.SetShortcut,self.QS,sc);
		end
	end
	self.SizeChanged=function(sender,args)
		local width,height=self:GetSize();
		self.QS:SetWidth(width+36);
		self.QS:SetHeight(height);
		self.Label:SetWidth(width);
		self.Label:SetHeight(height);
	end
	self.SetFont=function(sender,font)
		self.Label:SetFont(font);
	end
	self.SetBackground=function(sender,background)
		self.Label:SetBackground(background);
	end
	self.SetTextAlignment=function(sender,align)
		self.Label:SetTextAlignment(align)
	end
	self.SetText=function(sender,text)
		self.Label:SetText(text);
	end
	self.SetForeColor=function(sender,color)
		self.Label:SetForeColor(color);
	end
	self.SetBackColor=function(sender,color)
		self.Label:SetBackColor(color);
	end
end